@@ -36,7 +36,7 @@ Extender - Dynamically enhance Perl objects with additional methods from other m
 
 =head1 DESCRIPTION
 
-    Extender is a Perl module that facilitates the dynamic extension of objects with methods from other modules or custom-defined subroutines. It allows you to enhance Perl objects - whether hash references, array references, or scalar references - with additional functionalities without altering their original definitions.
+Extender is a Perl module that facilitates the dynamic extension of objects with methods from other modules or custom-defined subroutines. It allows you to enhance Perl objects - whether hash references, array references, or scalar references - with additional functionalities without altering their original definitions.
 
 =head1 EXPORTED FUNCTIONS
 
@@ -44,7 +44,7 @@ Extender - Dynamically enhance Perl objects with additional methods from other m
 
 =head2 Extend($object, $module, @methods)
 
-    Extends an object with methods from a specified module.
+Extends an object with methods from a specified module.
 
 =head3 Arguments:
 
@@ -60,7 +60,7 @@ Extender - Dynamically enhance Perl objects with additional methods from other m
 
 =head3 Description:
 
-    This function extends the specified C<$object> by importing methods from the module C<$module>. It dynamically loads the module if it's not already loaded, retrieves the list of exported functions, and adds each specified function as a method to the object.
+This function extends the specified C<$object> by importing methods from the module C<$module>. It dynamically loads the module if it's not already loaded, retrieves the list of exported functions, and adds each specified function as a method to the object.
 
 =head3 Example:
 
@@ -98,7 +98,7 @@ sub Extend {
 
 =head2 Extends($object, %extend)
 
-    Extends an object with custom methods.
+Extends an object with custom methods.
 
 =head3 Arguments:
 
@@ -112,7 +112,7 @@ sub Extend {
 
 =head3 Description:
 
-    This function extends the specified C<$object> by adding custom methods defined in C<%extend>. Each key-value pair in C<%extend> corresponds to a method name and its associated subroutine reference. If the method name already exists in C<$object>, it will override it.
+This function extends the specified C<$object> by adding custom methods defined in C<%extend>. Each key-value pair in C<%extend> corresponds to a method name and its associated subroutine reference. If the method name already exists in C<$object>, it will override it.
 
 =head3 Example:
 
@@ -155,7 +155,7 @@ sub Extends {
 
 =head2 Override($object, $method_name, $new_method)
 
-    Overrides an existing method in the object with a new implementation.
+Overrides an existing method in the object with a new implementation.
 
 =head3 Arguments:
 
@@ -171,7 +171,7 @@ sub Extends {
 
 =head3 Description:
 
-    This function overrides an existing method in the object with a new implementation provided as C<$new_method>. It allows for dynamic replacement of method behavior in Perl objects.
+This function overrides an existing method in the object with a new implementation provided as C<$new_method>. It allows for dynamic replacement of method behavior in Perl objects.
 
 =head3 Example:
 
@@ -213,7 +213,7 @@ sub Override {
 
 =head2 Alias($object, $existing_method, $new_name)
 
-    Creates an alias for an existing method in the object with a new name.
+Creates an alias for an existing method in the object with a new name.
 
 =head3 Arguments:
 
@@ -229,7 +229,7 @@ sub Override {
 
 =head3 Description:
 
-    This function creates an alias for an existing method in the object with a new name. It allows referencing the same method implementation using different names within the same object.
+This function creates an alias for an existing method in the object with a new name. It allows referencing the same method implementation using different names within the same object.
 
 =head3 Example:
 
@@ -272,7 +272,7 @@ sub Alias {
 
 =head2 Unload($object, @methods)
 
-    Removes specified methods from the object's namespace.
+Removes specified methods from the object's namespace.
 
 =head3 Arguments:
 
@@ -329,7 +329,7 @@ sub Unload {
 
 =head2 AddMethod($object, $method_name, $code_ref)
 
-    Adds a new method to the object.
+Adds a new method to the object.
 
 =head3 Arguments:
 
@@ -345,7 +345,7 @@ sub Unload {
 
 =head3 Description:
 
-    This function adds a new method to the object's namespace. It validates the method name and code reference before adding it to the object.
+This function adds a new method to the object's namespace. It validates the method name and code reference before adding it to the object.
 
 =head3 Example:
 
@@ -382,7 +382,7 @@ sub AddMethod {
 
 =head2 Decorate($object, $method_name, $decorator)
 
-    Decorates an existing method of an object with a custom decorator.
+Decorates an existing method of an object with a custom decorator.
 
 =head3 Arguments:
 
@@ -398,7 +398,7 @@ sub AddMethod {
 
 =head3 Description:
 
-    This function allows decorating an existing method of an object with a custom decorator function. The original method is replaced with a new subroutine that invokes the decorator function before and/or after invoking the original method.
+This function allows decorating an existing method of an object with a custom decorator function. The original method is replaced with a new subroutine that invokes the decorator function before and/or after invoking the original method.
 
 =head3 Example:
 
@@ -470,7 +470,7 @@ sub Decorate {
 
 =head2 ApplyRole($object, $role_class)
 
-    Applies a role (mixin) to an object, importing and applying its methods.
+Applies a role (mixin) to an object, importing and applying its methods.
 
 =head3 Arguments:
 
@@ -484,7 +484,7 @@ sub Decorate {
 
 =head3 Description:
 
-    This function loads a role class using C<require>, imports its methods into the current package, and applies them to the object using C<apply>.
+This function loads a role class using C<require>, imports its methods into the current package, and applies them to the object using C<apply>.
 
 =head3 Example:
 
@@ -540,7 +540,7 @@ sub ApplyRole {
 
 =head2 InitHook($object, $hook_name, $hook_code)
 
-    Adds initialization or destruction hooks to an object.
+Adds initialization or destruction hooks to an object.
 
 =head3 Arguments:
 
@@ -556,7 +556,7 @@ sub ApplyRole {
 
 =head3 Description:
 
-    This function adds a code reference to the specified hook array (`_init_hooks` or `_destruct_hooks`) in the object. Hooks can be executed during object initialization or destruction phases.
+This function adds a code reference to the specified hook array (`_init_hooks` or `_destruct_hooks`) in the object. Hooks can be executed during object initialization or destruction phases.
 
 =head3 Example:
 
@@ -635,7 +635,7 @@ sub InitHook {
 
 =head2 GenerateMethod($object, $method_name, $generator_code)
 
-    Generates a method on an object using a generator code reference.
+Generates a method on an object using a generator code reference.
 
 =head3 Arguments:
 
@@ -651,7 +651,7 @@ sub InitHook {
 
 =head3 Description:
 
-    This function dynamically generates a new method on the specified object using the provided generator code reference (`$generator_code`). The generator code receives the object reference (`$self`) as the first argument, followed by any additional arguments passed to the method.
+This function dynamically generates a new method on the specified object using the provided generator code reference (`$generator_code`). The generator code receives the object reference (`$self`) as the first argument, followed by any additional arguments passed to the method.
 
 =head3 Example:
 
@@ -693,7 +693,7 @@ sub GenerateMethod {
 
 =head2 MooseCompat($object, $role_name)
 
-    Applies a Moose role to an object using MooseX::Role::Parameterized::Extender::$role_name.
+Applies a Moose role to an object using MooseX::Role::Parameterized::Extender::$role_name.
 
 =head3 Arguments:
 
@@ -707,8 +707,8 @@ sub GenerateMethod {
 
 =head3 Description:
 
-    This function attempts to apply a Moose role specified by C<$role_name> to the given object C<$object>.
-    It dynamically loads the Moose role module using C<require>, applies it to the object, and handles any errors that occur during this process.
+This function attempts to apply a Moose role specified by C<$role_name> to the given object C<$object>.
+It dynamically loads the Moose role module using C<require>, applies it to the object, and handles any errors that occur during this process.
 
 =head3 Example:
 
@@ -1049,6 +1049,44 @@ sub MooseCompat {
 
     1;
 
+=head2 Creating Extender Class objects from any (even shared) reference typed variable
+
+    package main;
+
+    use Extender;
+
+    my $object = Extend({},'Extender');
+
+    # Define a method with the same name as an existing method
+    $object->Extends(
+        method => sub { return "method"; },
+    );
+
+    # Using the method
+    print $object->method(), "\n";  # Outputs: method
+
+    my $array = Extend([],'Extender');
+
+    # Define a method with the same name as an existing method
+    $array->Extends(
+        method => sub { return "method"; },
+    );
+
+    # Using the method
+    print $array->method(), "\n";  # Outputs: method
+
+    my $scalar = Extend(\"",'Extender');
+
+    # Define a method with the same name as an existing method
+    $scalar->Extends(
+        method => sub { return "method"; },
+    );
+
+    # Using the method
+    print $scalar->method(), "\n";  # Outputs: method
+
+    1;
+
 =cut
 
 =head1 AUTHOR
